
/**
 * Earth's hemispheres.
 */
export declare enum Hemisphere {
    Northern = 0,
    Southern = 1
}

export declare module JulianDay {
    /**
     * Julian day from Gregorian date.
     * @param date - Gregorian date to convert to Julian day.
     */
    const fromDate: (date?: Date) => number;
    /**
     * Gregorian date from Julian day
     * @param julian - Julian dat to convert to Gregorian date
     */
    const toDate: (julian: number) => Date;
}

/**
 * Enumeration of lunar phases as emoji.
 */
export declare module LunarEmoji {
    /**
     * Enumeration of lunar phases as emoji for the Northern Hemisphere.
     */
    export enum NorthernHemisphere {
        New = "\uD83C\uDF11",
        WaxingCrescent = "\uD83C\uDF12",
        FirstQuarter = "\uD83C\uDF13",
        WaxingGibbous = "\uD83C\uDF14",
        Full = "\uD83C\uDF15",
        WaningGibbous = "\uD83C\uDF16",
        LastQuarter = "\uD83C\uDF17",
        WaningCrescent = "\uD83C\uDF18"
    }
    /**
     * Enumeration of lunar phases as emoji for the Southern Hemisphere.
     */
    export enum SouthernHemisphere {
        New = "\uD83C\uDF11",
        WaxingCrescent = "\uD83C\uDF18",
        FirstQuarter = "\uD83C\uDF17",
        WaxingGibbous = "\uD83C\uDF16",
        Full = "\uD83C\uDF15",
        WaningGibbous = "\uD83C\uDF14",
        LastQuarter = "\uD83C\uDF13",
        WaningCrescent = "\uD83C\uDF12"
    }
}

export declare module LunarMonth {
    /**
     * Length of one synodic month, or days for the phases to complete a cycle.
     * Time between two identical syzygies, equivalent of 29.53059 Earth days.
     *
     * Based on Mean Synodic Month, 2000 AD mean solar days.
     */
    const length: number;
}

/**
 * Enumeration of lunar phases
 */
export declare enum LunarPhase {
    New = "New",
    WaxingCrescent = "Waxing Crescent",
    FirstQuarter = "First Quarter",
    WaxingGibbous = "Waxing Gibbous",
    Full = "Full",
    WaningGibbous = "Waning Gibbous",
    LastQuarter = "Last Quarter",
    WaningCrescent = "Waning Crescent"
}

export declare module LunationNumber {
    /**
     * Lunation 1 as the first new moon of 1923 at
     * approximately 02:41 UTC, January 17, 1923
     * per Ernest William Brown's lunar theory.
     */
    const baseLunationJulianDate = 2423436.6115277777;
}

export declare module Moon {
    /**
     * Moon's age, or days since the last new moon.
     *
     * @param date - Date used for calculation.
     * @returns Age of the moon, normalized within a 29.53059 Earth days calendar.
     */
    const lunarAge: (date?: Date) => number;
    /**
     * Percentage through the lunar synodic month.
     *
     * @param date - Date used for calculation.
     * @returns Percentage through the lunar month.
     */
    const lunarAgePercent: (date?: Date) => number;
    /**
     * Name of the lunar phase per date submitted.
     *
     * @param date - Date used to calculate lunar phase.
     * @returns Name as string of the current lunar phase.
     */
    const lunarPhase: (date?: Date) => LunarPhase;
    /**
     * Emoji of the lunar phase per date submitted.
     *
     * @param date - Date used to calculate lunar phase.
     * @param hemisphere - Northern or Southern Hemisphere.
     * @returns Emoji of the current lunar phase.
     */
    const lunarPhaseEmoji: (date?: Date, hemisphere?: Hemisphere) => string;
    /**
     * Brown Lunation Number (BLN), per Ernest William Brown's lunar theory,
     * defining Lunation 1 as the first new moon of 1923 at
     * approximately 02:41 UTC, January 17, 1923
     *
     * @param date
     */
    const lunationNumber: (date?: Date) => number;
    /**
     * Emoji for specified lunar phase
     *
     * @param phase - Lunar phase, per the LunarPhase enum
     * @param hemisphere - Northern or Southern Hemisphere.
     * @returns Emoji of the current lunar phase.
     */
    const emojiForLunarPhase: (phase: LunarPhase, hemisphere?: Hemisphere) => string;
    /**
     * Whether the moon is currently waxing (growing).
     *
     * @param date - Date used for calculation.
     * @returns True if moon is waxing.
     */
    const isWaxing: (date?: Date) => boolean;
    /**
     * Whether the moon is currently waning (shrinking).
     *
     * @param date - Date used for calculation.
     * @returns True if moon is waning.
     */
    const isWaning: (date?: Date) => boolean;
    /**
     * Normalization utility for percentage calculations.
     *
     * @param value - Percent value.
     */
    const normalize: (value: number) => number;
}

export { }
